@@ -2,14 +2,14 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2020-10-11
+# Release 2020-10-12
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.0
+MAKERESOLVEDEB_VERSION=1.1
 
 check_command() {
     echo -n "Checking for ${1}..."
-    if [ ! -x "$(command -v $1)" ]; then
+    if [[ ! -x "$(command -v $1)" ]]; then
 	echo "Missing! Sorry, seed '$1' to continue."
 	exit 1
     fi
@@ -17,10 +17,10 @@ check_command() {
 }
 
 copy_object() {
-    if [ -e "$1" ] ; then
+    if [[ -e "$1" ]] ; then
 	#echo "[COPY] $1 [TO] $2"
-	cp -rp "$1" "$2"
-	if [ $? -ne 0 ] ; then
+	if ! cp -rp "$1" "$2";
+	then
 	    ERRORS=$((ERRORS+1))
 	fi
     else
@@ -35,7 +35,7 @@ link_object() {
 }
 
 create_directory() {
-    if [ -e "$1" ] ; then
+    if [[ -e "$1" ]] ; then
 	echo "[ERROR: DIRECTORY EXISTS] $1"
 	ERRORS=$((ERRORS+1))
     else
@@ -45,7 +45,7 @@ create_directory() {
 }
 
 createf_directory() {
-    if [ -e "${1}" ] ; then
+    if [[ -e "${1}" ]] ; then
 	chmod a+w -R ${1}
 	rm -rf ${1}
     fi
@@ -63,9 +63,9 @@ remove_directory() {
 }
 
 extract_tgz() {
-    if [ -f "$1" ] ; then
+    if [[ -f "$1" ]] ; then
 	#echo "[EXTRACT] $1 [TO] $2/$3"
-	tar -zxf "$1" -C "$2" $3
+	tar -zxf "$1" -C "$2" "$3"
     else
 	echo "[ERROR: MISSING] $1"
 	ERRORS=$((ERRORS+1))
@@ -73,7 +73,7 @@ extract_tgz() {
 }
 
 make_executable() {
-    if [ -e "$1" ] ; then
+    if [[ -e "$1" ]] ; then
 	#echo "[MAKE EXECUTABLE] $1"
 	chmod a+x "$1"
     else
@@ -182,7 +182,10 @@ process16() {
     copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
-    copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
+    if ! [[ "$RESOLVE_VERSION" == 16.0b* ]];
+    then
+	copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
+    fi
     copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
     copy_object ${UNPACK_DIR}/scripts/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
@@ -192,8 +195,8 @@ process16() {
     copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/share/
 
     # Extract panel API library
-    create_directory ${DEB_DIR}/usr/lib/x86_64-linux-gnu
-    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/x86_64-linux-gnu libDaVinciPanelAPI.so
+    create_directory ${DEB_DIR}/usr/lib
+    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
 
     # Create symlinks
     create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
@@ -210,19 +213,21 @@ chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
-test ! -e /usr/lib64 && mkdir /usr/lib64 && touch /usr/lib64.by.makeresolvedeb
-test ! -h /usr/lib64/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib64/libDaVinciPanelAPI.so
-test ! -h /usr/lib/libDaVinciPanelAPI.so && ln -s /usr/lib/x86_64-linux-gnu/libDaVinciPanelAPI.so /usr/lib/libDaVinciPanelAPI.so
 EOF
     
-    # Add postrm commands
-    cat >> ${DEB_DIR}/DEBIAN/postrm <<EOF
-test -h /usr/lib/libDaVinciPanelAPI.so && rm /usr/lib/libDaVinciPanelAPI.so
-test -h /usr/lib64/libDaVinciPanelAPI.so && rm /usr/lib64/libDaVinciPanelAPI.so
-test -e /usr/lib64.by.makeresolvedeb && rmdir /usr/lib64 && rm /usr/lib64.by.makeresolvedeb
-EOF
+    # libcudafix for Resolve 16.0 & 16.1
+    if [[ "$RESOLVE_VERSION" == 16.0* ]] || [[ "$RESOLVE_VERSION" == 16.1* ]];
+    then
+	echo "Implementing libcudafix"
+	echo "test ! -e /usr/lib64 && mkdir /usr/lib64 && touch /usr/lib64.by.makeresolvedeb" >> ${DEB_DIR}/DEBIAN/postinst
+	echo "test ! -h /usr/lib64/libcuda.so && ln -s /usr/lib/x86_64-linux-gnu/libcuda.so /usr/lib64/libcuda.so && touch /usr/lib64/libcuda.so.by.makeresolvedeb" >> ${DEB_DIR}/DEBIAN/postinst
+	echo "test -e /usr/lib64/libcuda.so.by.makeresolvedeb && rm /usr/lib64/libcuda.so && rm /usr/lib64/libcuda.so.by.makeresolvedeb" >> ${DEB_DIR}/DEBIAN/postrm
+	echo "test -e /usr/lib64.by.makeresolvedeb && rmdir /usr/lib64 && rm /usr/lib64.by.makeresolvedeb" >> ${DEB_DIR}/DEBIAN/postrm
+    fi
 }
 
+echo "MakeResolveDeb ${MAKERESOLVEDEB_VERSION}"
+
 # Check argument
 case $1 in
     *.run)
@@ -240,29 +245,27 @@ case $1 in
 esac
 
 # Check if file exists
-if [ ! -e $INSTALLER_ARCHIVE ];
+if [[ ! -e $INSTALLER_ARCHIVE ]];
 then
     echo "[ERROR] File does not exist"
     exit 1
 fi
 
 # Validate and parse archive name
-if [ "$FILENAMEP1" != "DaVinci" ] || [ "$FILENAMEP2" != "Resolve" ];
+if [[ "$FILENAMEP1" != "DaVinci" ]] || [[ "$FILENAMEP2" != "Resolve" ]];
 then
-    echo "ERROR: File does not look like a valid DaVinci Resolve installer archive"
+    echo "[ERROR] File does not look like a valid DaVinci Resolve installer archive"
     exit 1
 fi
-if [ "$FILENAMEP5" == "Linux.run" ] && [ "$FILENAMEP3" == "Studio" ];
+if [[ "$FILENAMEP5" == "Linux.run" ]] && [[ "$FILENAMEP3" == "Studio" ]];
 then
     RESOLVE_NAME="DaVinci Resolve Studio"
-    RESOLVE_STUDIO=yes
     RESOLVE_VERSION=$FILENAMEP4
     DEB_NAME=davinci-resolve-studio
     DEB_CONFLICTS=davinci-resolve
-elif [ "$FILENAMEP4" == "Linux.run" ];
+elif [[ "$FILENAMEP4" == "Linux.run" ]];
 then
     RESOLVE_NAME="DaVinci Resolve"
-    RESOLVE_STUDIO=no
     RESOLVE_VERSION=$FILENAMEP3
     DEB_NAME=davinci-resolve
     DEB_CONFLICTS=davinci-resolve-studio
@@ -270,7 +273,7 @@ else
     echo "[ERROR] File does not look like a valid DaVinci Resolve installer archive"
     exit 1
 fi
-UNPACK_DIR=./unpack-$DEB_NAME-$RESOLVE_VERSION
+UNPACK_DIR=./unpack-${DEB_NAME}-${RESOLVE_VERSION}
 DEB_VERSION=${RESOLVE_VERSION}-mrd${MAKERESOLVEDEB_VERSION}
 DEB_DIR=./${DEB_NAME}_${DEB_VERSION}_amd64
 RESOLVE_BASE_DIR=${DEB_DIR}/opt/resolve
@@ -361,8 +364,9 @@ EOF
 
 # Create Debian package
 close_deb
-fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb
-if [ $? -ne 0 ] ; then
+echo "Creating Debian package"
+if ! fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb;
+then
     ERRORS=$((ERRORS+1))
 fi
 
